@@ -8,11 +8,7 @@ from shutil import copyfile
 
 
 class Cfg():
-    """Represent the bronotes config.
-
-    Merges multiple levels of config and manages a single source of truth.
-    Reads from defaults, flags, and user defined files.
-    """
+    """Represent the bronotes config."""
 
     def __init__(self):
         """Construct the config manager."""
@@ -32,6 +28,12 @@ class Cfg():
         self.__write_cfg()
         self.__load_cfg()
 
+    def set_default_action(self, action):
+        """Set a default action."""
+        self.dict['default_action'] = str(action)
+        self.__write_cfg()
+        self.__load_cfg()
+
     def enable_autosync(self):
         """Enable auto syncing."""
         self.dict['autosync'] = True
@@ -64,6 +66,11 @@ class Cfg():
         else:
             self.dir = None
 
+        if 'default_action' in self.dict:
+            self.default_action = self.dict['default_action']
+        else:
+            self.default_action = 'list'
+
         try:
             self.autosync = self.dict['autosync']
         except KeyError:
@@ -96,7 +103,6 @@ class Cfg():
         self.__load_cfg()
 
 
-# TODO This was a horrible idea.
 class Text(Enum):
     """Module-level text constants.
 
